@@ -1,11 +1,9 @@
 package DateTime::TimeZone;
 
-use 5.006;
-
 use strict;
-use warnings;
 
-our $VERSION = '0.7701';
+use vars qw( $VERSION );
+$VERSION = '0.28';
 
 use DateTime::TimeZoneCatalog;
 use DateTime::TimeZone::Floating;
@@ -14,8 +12,8 @@ use DateTime::TimeZone::OffsetOnly;
 use DateTime::TimeZone::UTC;
 use Params::Validate qw( validate validate_pos SCALAR ARRAYREF BOOLEAN );
 
-use constant INFINITY     =>       100 ** 1000 ;
-use constant NEG_INFINITY => -1 * (100 ** 1000);
+use constant INFINITY     =>       100 ** 100 ** 100 ;
+use constant NEG_INFINITY => -1 * (100 ** 100 ** 100);
 
 # the offsets for each span element
 use constant UTC_START   => 0;
@@ -26,8 +24,6 @@ use constant OFFSET      => 4;
 use constant IS_DST      => 5;
 use constant SHORT_NAME  => 6;
 
-my %SpecialName = map { $_ => 1 } qw( EST MST HST EST5EDT CST6CDT MST7MDT PST8PDT );
-
 sub new
 {
     my $class = shift;
@@ -44,9 +40,7 @@ sub new
         $p{name} = $DateTime::TimeZone::LINKS{ uc $p{name} };
     }
 
-    unless ( $p{name} =~ m,/,
-             || $SpecialName{ $p{name} }
-           )
+    unless ( $p{name} =~ m,/, )
     {
         if ( $p{name} eq 'floating' )
         {
@@ -55,7 +49,7 @@ sub new
 
         if ( $p{name} eq 'local' )
         {
-            return DateTime::TimeZone::Local->TimeZone();
+            return DateTime::TimeZone::Local::local_time_zone();
         }
 
         if ( $p{name} eq 'UTC' || $p{name} eq 'Z' )
@@ -71,9 +65,6 @@ sub new
     $subclass =~ s{/}{::}g;
     my $real_class = "DateTime::TimeZone::$subclass";
 
-    die "The timezone '$p{name}' in an invalid name.\n"
-        unless $real_class =~ /^\w+(::\w+)*$/;
-
     unless ( $real_class->can('instance') )
     {
         eval "require $real_class";
@@ -94,23 +85,7 @@ sub new
         }
     }
 
-    my $zone = $real_class->instance( name => $p{name}, is_olson => 1 );
-
-    if ( $zone->is_olson() )
-    {
-        my $object_version =
-            $zone->can('olson_version')
-            ? $zone->olson_version()
-            : 'unknown';
-        my $catalog_version = __PACKAGE__->catalog_olson_version();
-
-        if ( $object_version ne $catalog_version )
-        {
-            warn "Loaded $real_class, which is from an older version ($object_version) of the Olson database than this installation of DateTime::TimeZone ($catalog_version).\n";
-        }
-    }
-
-    return $zone;
+    return $real_class->instance( name => $p{name}, is_olson => 1 );
 }
 
 sub _init
@@ -259,13 +234,6 @@ sub _spans_binary_search
             if ( $current->[IS_DST] && $type eq 'local' )
             {
                 my $next = $self->{spans}[$i + 1];
-                # Sometimes we will get here and the span we're
-                # looking at is the last that's been generated so far.
-                # We need to try to generate one more or else we run
-                # out.
-                $next ||= $self->_generate_next_span;
-
-                die "No next span in $self->{max_year}" unless defined $next;
 
                 if ( ( ! $next->[IS_DST] )
                      && $next->[$start] <= $seconds
@@ -281,25 +249,6 @@ sub _spans_binary_search
     }
 }
 
-sub _generate_next_span
-{
-    my $self = shift;
-
-    my $last_idx = $#{ $self->{spans} };
-
-    my $max_span = $self->max_span;
-
-    # Kind of a hack, but AFAIK there are no zones where it takes
-    # _more_ than a year for a _future_ time zone change to occur, so
-    # by looking two years out we can ensure that we will find at
-    # least one more span.  Of course, I will no doubt be proved wrong
-    # and this will cause errors.
-    $self->_generate_spans_until_match
-        ( $self->{max_year} + 2, $max_span->[UTC_END] + ( 366 * 86400 ), 'utc' );
-
-    return $self->{spans}[ $last_idx + 1 ];
-}
-
 sub _generate_spans_until_match
 {
     my $self = shift;
@@ -399,20 +348,14 @@ sub is_floating { 0 }
 
 sub is_utc { 0 }
 
-sub has_dst_changes { 0 }
-
 sub name      { $_[0]->{name} }
 sub category  { (split /\//, $_[0]->{name}, 2)[0] }
 
 sub is_valid_name
 {
-    my $tz;
-    {
-        local $@;
-        $tz = eval { $_[0]->new( name => $_[1] ) };
-    }
+    my $tz = eval { $_[0]->new( name => $_[1] ) };
 
-    return $tz && $tz->isa('DateTime::TimeZone') ? 1 : 0
+    return $tz && UNIVERSAL::isa( $tz, 'DateTime::TimeZone') ? 1 : 0
 }
 
 sub STORABLE_freeze
@@ -440,9 +383,12 @@ sub STORABLE_thaw
         $obj = $class->new( name => $serialized );
     }
 
+    # This breaks the "singleton-ness" of timezone objects, but
+    # there's no way to tell Storable to simply use an existing
+    # object.  This shouldn't matter since we copy the underlying
+    # structures by reference here, so span generation in one object
+    # will be visible in another also in memory.
     %$self = %$obj;
-
-    return $self;
 }
 
 #
@@ -450,11 +396,6 @@ sub STORABLE_thaw
 #
 sub offset_as_seconds
 {
-    {
-        local $@;
-        shift if eval { $_[0]->isa('DateTime::TimeZone') };
-    }
-
     my $offset = shift;
 
     return undef unless defined $offset;
@@ -489,11 +430,6 @@ sub offset_as_seconds
 
 sub offset_as_string
 {
-    {
-        local $@;
-        shift if eval { $_[0]->isa('DateTime::TimeZone') };
-    }
-
     my $offset = shift;
 
     return undef unless defined $offset;
@@ -515,56 +451,6 @@ sub offset_as_string
            );
 }
 
-# These methods all operate on data contained in the DateTime/TimeZoneCatalog.pm file.
-
-sub all_names
-{
-    return wantarray ? @DateTime::TimeZone::ALL : [@DateTime::TimeZone::ALL];
-}
-
-sub categories
-{
-    return wantarray
-        ? @DateTime::TimeZone::CATEGORY_NAMES
-        : [@DateTime::TimeZone::CATEGORY_NAMES];
-}
-
-sub links
-{
-    return
-        wantarray ? %DateTime::TimeZone::LINKS : {%DateTime::TimeZone::LINKS};
-}
-
-sub names_in_category
-{
-    shift if $_[0]->isa('DateTime::TimeZone');
-    return unless exists $DateTime::TimeZone::CATEGORIES{ $_[0] };
-
-    return
-        wantarray
-        ? @{ $DateTime::TimeZone::CATEGORIES{ $_[0] } }
-        : [ $DateTime::TimeZone::CATEGORIES{ $_[0] } ];
-}
-
-sub countries
-{
-    wantarray
-        ? ( sort keys %DateTime::TimeZone::ZONES_BY_COUNTRY )
-        : [ sort keys %DateTime::TimeZone::ZONES_BY_COUNTRY ];
-}
-
-sub names_in_country
-{
-    shift if $_[0]->isa('DateTime::TimeZone');
-
-    return unless exists $DateTime::TimeZone::ZONES_BY_COUNTRY{ lc $_[0] };
-
-    return
-        wantarray
-        ? @{ $DateTime::TimeZone::ZONES_BY_COUNTRY{ lc $_[0] } }
-        : $DateTime::TimeZone::ZONES_BY_COUNTRY{ lc $_[0] };
-}
-
 
 1;
 
@@ -577,7 +463,7 @@ DateTime::TimeZone - Time zone object base class and factory
 =head1 SYNOPSIS
 
   use DateTime;
-  use DateTime::TimeZone;
+  use DateTime::TimeZone
 
   my $tz = DateTime::TimeZone->new( name => 'America/Chicago' );
 
@@ -599,7 +485,9 @@ methods.
 
 This class has the following methods:
 
-=head2 DateTime::TimeZone->new( name => $tz_name )
+=over 4
+
+=item * new( name => $tz_name )
 
 Given a valid time zone name, this method returns a new time zone
 blessed into the appropriate subclass.  Subclasses are named for the
@@ -610,13 +498,6 @@ If the name given is a "link" name in the Olson database, the object
 created may have a different name.  For example, there is a link from
 the old "EST5EDT" name to "America/New_York".
 
-When loading a time zone from the Olson database, the constructor
-checks the version of the loaded class to make sure it matches the
-version of the current DateTime::TimeZone installation. If they do not
-match it will issue a warning. This is useful because time zone names
-may fall out of use, but you may have an old module file installed for
-that time zone.
-
 There are also several special values that can be given as names.
 
 If the "name" parameter is "floating", then a
@@ -632,6 +513,8 @@ object is returned.
 If the "name" is an offset string, it is converted to a number, and a
 C<DateTime::TimeZone::OffsetOnly> object is returned.
 
+=back
+
 =head3 The "local" time zone
 
 If the "name" parameter is "local", then the module attempts to
@@ -661,19 +544,25 @@ with the name contained in the file.
 
 Finally, it checks for a file called F</etc/sysconfig/clock>.  If this
 file exists, it looks for a line inside the file matching
-C</^(?:TIME)?ZONE="([^"]+)"/>.  If this line exists, it tries the
-value as a time zone name.
+C</^(?:TIME)ZONE="([^"]+)"/>.  If this line exists, it tries the value as a
+time zone name.
 
 If none of these methods work, it gives up and dies.
 
-=head2 $tz->offset_for_datetime( $dt )
+=head2 Object Methods
+
+C<DateTime::TimeZone> objects provide the following methods:
+
+=over 4
+
+=item * offset_for_datetime( $dt )
 
 Given a C<DateTime> object, this method returns the offset in seconds
 for the given datetime.  This takes into account historical time zone
 information, as well as Daylight Saving Time.  The offset is
 determined by looking at the object's UTC Rata Die days and seconds.
 
-=head2 $tz->offset_for_local_datetime( $dt )
+=item * offset_for_local_datetime( $dt )
 
 Given a C<DateTime> object, this method returns the offset in seconds
 for the given datetime.  Unlike the previous method, this method uses
@@ -681,12 +570,12 @@ the local time's Rata Die days and seconds.  This should only be done
 when the corresponding UTC time is not yet known, because local times
 can be ambiguous due to Daylight Saving Time rules.
 
-=head2 $tz->name
+=item * name
 
 Returns the name of the time zone.  If this value is passed to the
 C<new()> method, it is guaranteed to create the same object.
 
-=head2 $tz->short_name_for_datetime( $dt )
+=item * short_name_for_datetime( $dt )
 
 Given a C<DateTime> object, this method returns the "short name" for
 the current observance and rule this datetime is in.  These are names
@@ -698,84 +587,87 @@ of them are simply the invention of the Olson database maintainers.
 Moreover, these names are not unique.  For example, there is an "EST"
 at both -0500 and +1000/+1100.
 
-=head2 $tz->is_floating
+=item * is_floating
 
 Returns a boolean indicating whether or not this object represents a
 floating time zone, as defined by RFC 2445.
 
-=head2 $tz->is_utc
+=item * is_utc
 
 Indicates whether or not this object represents the UTC (GMT) time
 zone.
 
-=head2 $tz->has_dst_changes
-
-Indicates whether or not this zone has I<ever> had a change to and
-from DST, either in the past or future.
-
-=head2 $tz->is_olson
+=item * is_olson
 
 Returns true if the time zone is a named time zone from the Olson
 database.
 
-=head2 $tz->category
+=item * category
 
 Returns the part of the time zone name before the first slash.  For
 example, the "America/Chicago" time zone would return "America".
 
-=head2 DateTime::TimeZone->is_valid_name($name)
+=back
+
+=head2 Class Methods
+
+This class provides one class method:
+
+=over 4
+
+=item * is_valid_name ($name)
 
 Given a string, this method returns a boolean value indicating whether
 or not the string is a valid time zone name.  If you are using
 C<DateTime::TimeZone::Alias>, any aliases you've created will be valid.
 
-=head2 DateTime::TimeZone->all_names
+=back
+
+=head2 Storable Hooks
+
+This module provides freeze and thaw hooks for C<Storable> so that the
+huge data structures for Olson time zones are not actually stored in
+the serialized structure.
+
+If you subclass C<DateTime::TimeZone>, you will inherit its hooks,
+which may not work for your module, so please test the interaction of
+your module with Storable.
+
+=head2 Functions
+
+This class also contains several functions, none of which are
+exported.
+
+=over 4
+
+=item * all_names
 
 This returns a pre-sorted list of all the time zone names.  This list
 does not include link names.  In scalar context, it returns an array
 reference, while in list context it returns an array.
 
-=head2 DateTime::TimeZone->categories
+=item * categories
 
 This returns a list of all time zone categories.  In scalar context,
 it returns an array reference, while in list context it returns an
 array.
 
-=head2 DateTime::TimeZone->links
+=item * links
 
 This returns a hash of all time zone links, where the keys are the
 old, deprecated names, and the values are the new names.  In scalar
 context, it returns a hash reference, while in list context it returns
 a hash.
 
-=head2 DateTime::TimeZone->names_in_category( $category )
+=item * names_in_category( $category )
 
 Given a valid category, this method returns a list of the names in
 that category, without the category portion.  So the list for the
 "America" category would include the strings "Chicago",
-"Kentucky/Monticello", and "New_York". In scalar context, it returns
+"Kentucky/Monticello", and "New_York".  In scalar context, it returns
 an array reference, while in list context it returns an array.
 
-The list is returned in order of population by zone, which should mean
-that this order will be the best to use for most UIs.
-
-=head2 DateTime::TimeZone->countries()
-
-Returns a sorted list of all the valid country codes (in lower-case)
-which can be passed to C<names_in_country()>. In scalar context, it
-returns an array reference, while in list context it returns an array.
-
-If you need to convert country codes to names or vice versa you can
-use C<Locale::Country> to do so.
-
-=head2 DateTime::TimeZone->names_in_country( $country_code )
-
-Given a two-letter ISO3066 country code, this method returns a list of
-time zones used in that country. The country code may be of any
-case. In scalar context, it returns an array reference, while in list
-context it returns an array.
-
-=head2 DateTime::TimeZone->offset_as_seconds( $offset )
+=item * offset_as_seconds( $offset )
 
 Given an offset as a string, this returns the number of seconds
 represented by the offset as a positive or negative number.  Returns
@@ -789,25 +681,17 @@ these, C<undef> will be returned.
 This means that if you want to specify hours as a single digit, then
 each element of the offset must be separated by a colon (:).
 
-=head2 DateTime::TimeZone->offset_as_string( $offset )
+=item * offset_as_string( $offset )
 
 Given an offset as a number, this returns the offset as a string.
 Returns C<undef> if $offset is not in the range C<-359999> to C<359999>.
 
-=head2 Storable Hooks
-
-This module provides freeze and thaw hooks for C<Storable> so that the
-huge data structures for Olson time zones are not actually stored in
-the serialized structure.
-
-If you subclass C<DateTime::TimeZone>, you will inherit its hooks,
-which may not work for your module, so please test the interaction of
-your module with Storable.
+=back
 
 =head1 SUPPORT
 
 Support for this module is provided via the datetime@perl.org email
-list. See http://datetime.perl.org/?MailingList for details.
+list.  See http://lists.perl.org/ for more details.
 
 Please submit bugs to the CPAN RT system at
 http://rt.cpan.org/NoAuth/ReportBug.html?Queue=datetime%3A%3Atimezone
@@ -815,19 +699,14 @@ or via email at bug-datetime-timezone@rt.cpan.org.
 
 =head1 AUTHOR
 
-Dave Rolsky <autarch@urth.org>
-
-=head1 CREDITS
-
-This module was inspired by Jesse Vincent's work on
-Date::ICal::Timezone, and written with much help from the
-datetime@perl.org list.
+Dave Rolsky <autarch@urth.org>, inspired by Jesse Vincent's work on
+Date::ICal::Timezone, and with help from the datetime@perl.org list.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003-2008 David Rolsky.  All rights reserved.  This
-program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+Copyright (c) 2003 David Rolsky.  All rights reserved.  This program
+is free software; you can redistribute it and/or modify it under the
+same terms as Perl itself.
 
 The full text of the license can be found in the LICENSE file included
 with this module.
